==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/VerticalStackedSeriesBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StackedSeriesBaseDescriptionMetadata } from "./StackedSeriesBaseDescriptionMetadata";
/**
 * @hidden
 */
var VerticalStackedSeriesBaseDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(VerticalStackedSeriesBaseDescriptionMetadata, _super);
    function VerticalStackedSeriesBaseDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    VerticalStackedSeriesBaseDescriptionMetadata.b = function (a) {
        if (VerticalStackedSeriesBaseDescriptionMetadata.a == null) {
            VerticalStackedSeriesBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            VerticalStackedSeriesBaseDescriptionMetadata.c(VerticalStackedSeriesBaseDescriptionMetadata.a);
        }
        if (a.j(VerticalStackedSeriesBaseDescriptionMetadata.a)) {
            return;
        }
        a.y(VerticalStackedSeriesBaseDescriptionMetadata.a);
    };
    VerticalStackedSeriesBaseDescriptionMetadata.c = function (a) {
        StackedSeriesBaseDescriptionMetadata.c(a);
        a.item("XAxisRef", "(w:XAxis,wf:XAxis)DataRef::object");
        a.item("XAxisRef@nameBinding", "true");
        a.item("YAxisRef", "(w:YAxis,wf:YAxis)DataRef::object");
        a.item("YAxisRef@nameBinding", "true");
    };
    VerticalStackedSeriesBaseDescriptionMetadata.d = function (a) {
        VerticalStackedSeriesBaseDescriptionMetadata.b(a);
        a.z("VerticalStackedSeriesBase", VerticalStackedSeriesBaseDescriptionMetadata.a);
    };
    VerticalStackedSeriesBaseDescriptionMetadata.$t = markType(VerticalStackedSeriesBaseDescriptionMetadata, 'VerticalStackedSeriesBaseDescriptionMetadata');
    VerticalStackedSeriesBaseDescriptionMetadata.a = null;
    return VerticalStackedSeriesBaseDescriptionMetadata;
}(Base));
export { VerticalStackedSeriesBaseDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/VerticalStackedSeriesBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StackedSeriesBaseDescriptionMetadata } from "./StackedSeriesBaseDescriptionMetadata";
/**
 * @hidden
 */
var VerticalStackedSeriesBaseDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(VerticalStackedSeriesBaseDescriptionMetadata, _super);
    function VerticalStackedSeriesBaseDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    VerticalStackedSeriesBaseDescriptionMetadata.b = function (a) {
        if (VerticalStackedSeriesBaseDescriptionMetadata.a == null) {
            VerticalStackedSeriesBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            VerticalStackedSeriesBaseDescriptionMetadata.c(VerticalStackedSeriesBaseDescriptionMetadata.a);
        }
        if (a.k(VerticalStackedSeriesBaseDescriptionMetadata.a)) {
            return;
        }
        a.aa(VerticalStackedSeriesBaseDescriptionMetadata.a);
    };
    VerticalStackedSeriesBaseDescriptionMetadata.c = function (a) {
        StackedSeriesBaseDescriptionMetadata.c(a);
        a.item("XAxisRef", "(w:XAxis,wf:XAxis)DataRef::object");
        a.item("XAxisRef@nameBinding", "true");
        a.item("YAxisRef", "(w:YAxis,wf:YAxis)DataRef::object");
        a.item("YAxisRef@nameBinding", "true");
    };
    VerticalStackedSeriesBaseDescriptionMetadata.d = function (a) {
        VerticalStackedSeriesBaseDescriptionMetadata.b(a);
        a.ab("VerticalStackedSeriesBase", VerticalStackedSeriesBaseDescriptionMetadata.a);
    };
    VerticalStackedSeriesBaseDescriptionMetadata.$t = markType(VerticalStackedSeriesBaseDescriptionMetadata, 'VerticalStackedSeriesBaseDescriptionMetadata');
    VerticalStackedSeriesBaseDescriptionMetadata.a = null;
    return VerticalStackedSeriesBaseDescriptionMetadata;
}(Base));
export { VerticalStackedSeriesBaseDescriptionMetadata };
